@@ -213,7 +213,6 @@ vis_toil_TvsN <- function(Gene = "TP53", Mode = c("Boxplot", "Violinplot"),
 #' }
 #' @export
 vis_unicox_tree <- function(Gene = "TP53", measure = "OS", data_type = "mRNA", threshold = 0.5, values = c("grey", "#E31A1C", "#377DB8")) {
-  ## 写在 R 内的数据集需要更严格的引用方式
   tcga_surv <- load_data("tcga_surv")
   tcga_gtex <- load_data("tcga_gtex")
 
@@ -249,9 +248,10 @@ vis_unicox_tree <- function(Gene = "TP53", measure = "OS", data_type = "mRNA", t
         dplyr::mutate(group = factor(.data$group, levels = c("low", "high")))
     }
 
-
     unicox_res_genes <- ezcox::ezcox(
-      sss_can,
+      sss_can %>%
+        dplyr::select(c("values", paste0(measure, ".time"), measure)) %>%
+        na.omit(),
       covariates = "values",
       time = paste0(measure, ".time"),
       status = measure,
@@ -281,7 +281,7 @@ vis_unicox_tree <- function(Gene = "TP53", measure = "OS", data_type = "mRNA", t
     ggplot2::theme_bw() +
     ggplot2::geom_pointrange() +
     ggplot2::coord_flip() +
-    ggplot2::labs(x = "", y = "log (Hazard Ratio)") +
+    ggplot2::labs(x = "", y = "ln (Hazard Ratio)") +
     ggtitle(paste0(Gene, if (startsWith(data_type, "mRNA") | startsWith(data_type, "miRNA")) " Expression" else "")) +
     ggplot2::theme(
       axis.text.x = element_text(color = "black"),
